! 23/09/2010
! In this file we define the standard values of the parameters we
! want to externalise. For the moment, we test with lai_max
! author : D.Solyga

MODULE constantes_mtc

USE defprec
USE constantes

IMPLICIT NONE



  !----------------------
  ! Metaclasses global
  !----------------------
  !
  ! Number of MTCS fixed in the code
  INTEGER(i_std), PARAMETER :: nvmc = 13

  ! description of the MTC
  CHARACTER(len=34), SAVE, DIMENSION(nvmc)              :: MTC_name = &
  & (/ 'bared ground                      ', &          !  1
  &    'tropical  broad-leaved evergreen  ', &          !  2
  &    'tropical  broad-leaved raingreen  ', &          !  3
  &    'temperate needleleaf   evergreen  ', &          !  4
  &    'temperate broad-leaved evergreen  ', &          !  5
  &    'temperate broad-leaved summergreen', &          !  6
  &    'boreal    needleleaf   evergreen  ', &          !  7
  &    'boreal    broad-leaved summergreen', &          !  8
  &    'boreal    needleleaf   summergreen', &          !  9
  &    '          C3           grass      ', &          ! 10
  &    '          C4           grass      ', &          ! 11
  &    '          C3           agriculture', &          ! 12
  &    '          C4           agriculture'  /)         ! 13


  !----------------------
  ! Vegetation structure 
  !----------------------
  !-
  ! 1 .Sechiba
  !-
  ! Value for veget_ori for tests in 0-dim simulations
  REAL(r_std), PARAMETER, DIMENSION(nvmc)   :: veget_ori_fixed_mtc = &
  & (/ 0.2, 0.0, 0.0, 0.0, 0.0, &
  &    0.0, 0.0, 0.0, 0.0, 0.8, &
  &    0.0, 0.0, 0.0 /)
  !-
  ! laimax for maximum lai see also type of lai interpolation
  REAL(r_std), PARAMETER, DIMENSION(nvmc)   :: llaimax_mtc = &
  & (/ 0., 8., 8., 4., 4.5, 4.5, 4., 4.5, 4., 2., 2., 2., 2./)
  !-
  ! laimin for minimum lai see also type of lai interpolation
  REAL(r_std), PARAMETER, DIMENSION(nvmc)   :: llaimin_mtc  = &
  & (/ 0., 8., 0., 4., 4.5, 0., 4., 0., 0., 0., 0., 0., 0./)
  !-
  ! prescribed height of vegetation.
  ! Value for height_presc : one for each vegetation type
  REAL(r_std), PARAMETER, DIMENSION(nvmc)   :: height_presc_mtc = &
  & (/ 0.,30.,30.,20.,20.,20.,15.,15.,15.,.5,.6,1.,1./)
  !-
  ! Type of behaviour of the LAI evolution algorithm
  ! for each vegetation type.
  ! Value of type_of_lai, one for each vegetation type : mean or interp
  CHARACTER(len=5),PARAMETER, DIMENSION(nvmc) :: type_of_lai_mtc = &
  & (/ 'inter', 'inter', 'inter', 'inter', 'inter', &
  &    'inter', 'inter', 'inter', 'inter', 'inter', &
  &    'inter', 'inter', 'inter' /)
  !-
  ! Is the vegetation type a tree ?
  LOGICAL,PARAMETER, DIMENSION(nvmc) :: is_tree_mtc   =  &
  & (/ .FALSE., .TRUE.,  .TRUE., .TRUE., .TRUE.,  &
  &    .TRUE.,  .TRUE.,  .TRUE., .TRUE., .FALSE., &
  &    .FALSE., .FALSE., .FALSE. /)
  ! used in diffuco
  REAL(r_std), PARAMETER, DIMENSION(nvmc)        :: rveg_mtc = &  
  & (/ 1., 1., 1., 1., 1., 1. ,1. ,1. ,1. ,1. ,1. ,1., 1. /)
  !
  !-
  ! 2 .Stomate
  !- 
  ! leaf type
  ! 1=broad leaved tree, 2=needle leaved tree, 3=grass 4=bared ground
  INTEGER(i_std),PARAMETER, DIMENSION(nvmc)  ::      leaf_tab_mtc  =   &
  & (/      4,       1,       1,       2,       1,       1,       2,   &
  &                  1,       2,       3,       3,       3,       3 /)
  !-
  ! specif leaf area (m**2/gC)
  REAL(r_std), PARAMETER, DIMENSION(nvmc)   ::     sla_mtc    =      &
  & (/ 1.5E-2, 1.53E-2,  2.6E-2, 9.26E-3,  2E-2,  2.6E-2,  9.26E-3,  &
  &        2.6E-2,  1.9E-2,  2.6E-2, 2.6E-2, 2.6E-2, 2.6E-2 /) 
  !-
  ! natural? 
  LOGICAL, PARAMETER, DIMENSION(nvmc)              :: natural_mtc  =    &
  & (/  .TRUE.,  .TRUE.,  .TRUE.,  .TRUE.,  .TRUE.,  .TRUE.,  .TRUE.,   &
  &              .TRUE.,  .TRUE.,  .TRUE.,  .TRUE., .FALSE., .FALSE. /)

  !>> DS new for merge in the trunk   ! 15/06/2011 
  ! Add for writing history files in stomate_lpj.f90 'treeFracPrimDec' and 'treeFracPrimEver'
  ! is PFT deciduous ?
  LOGICAL, PARAMETER, DIMENSION(nvmc)    :: is_deciduous_mtc  = &
  & (/  .FALSE.,  .FALSE.,  .TRUE.,  .FALSE.,  .FALSE.,  .TRUE.,  .FALSE.,   &
  &              .TRUE.,  .TRUE.,  .FALSE.,  .FALSE., .FALSE., .FALSE. /)
  ! is PFT evergreen ?
  LOGICAL, PARAMETER, DIMENSION(nvmc)    :: is_evergreen_mtc  = &
  & (/  .FALSE.,  .TRUE.,  .FALSE.,  .TRUE.,  .TRUE.,  .FALSE.,  .TRUE.,   &
  &              .FALSE.,  .FALSE.,  .FALSE.,  .FALSE., .FALSE., .FALSE. /)        
  ! is PFT C3 ?
  LOGICAL, PARAMETER, DIMENSION(nvmc)    :: is_c3_mtc = &  
  & (/.FALSE.,.FALSE.,.FALSE.,.FALSE.,.FALSE.,.FALSE.,         &
  &   .FALSE.,.FALSE.,.FALSE.,.TRUE.,.FALSE.,.TRUE.,.FALSE. /)

  !-------------------------------
  ! Evapotranspiration -  sechiba
  !-------------------------------
  !
  ! Structural resistance.
  ! Value for rstruct_const : one for each vegetation type
  REAL(r_std), PARAMETER, DIMENSION(nvmc)     :: rstruct_const_mtc = &
  & (/ 0.0, 25.0, 25.0, 25.0, 25.0, 25.0, 25.0,   &
  &   25.0, 25.0,  2.5,  2.0,  2.0,  2.0 /)
  !-
  ! A vegetation dependent constant used in the calculation
  ! of the surface resistance.
  ! Value for kzero one for each vegetation type
  REAL(r_std), PARAMETER, DIMENSION(nvmc)     ::  kzero_mtc  =  &
  & (/0.0, 12.E-5, 12.E-5, 12.e-5, 12.e-5, 25.e-5, 12.e-5,&
  &    25.e-5, 25.e-5, 30.e-5, 30.e-5, 30.e-5, 30.e-5     /)


  !-------------------
  ! Water - sechiba
  !-------------------
  !
  ! Maximum field capacity for each of the vegetations (Temporary).
  ! Value of wmax_veg : max quantity of water :
  ! one for each vegetation type en Kg/M3
  REAL(r_std), PARAMETER, DIMENSION(nvmc)     :: wmax_veg_mtc  = &
  & (/ 150., 150., 150., 150., 150., 150., 150., &
  &    150., 150., 150., 150., 150., 150. /)
  !-
  ! Root profile description for the different vegetation types.
  ! These are the factor in the exponential which gets
  ! the root density as a function of depth
  REAL(r_std), PARAMETER, DIMENSION(nvmc)     :: humcste_mtc  = &
  & (/5., .8, .8, 1., .8, .8, 1., 1., .8, 4., 4., 4., 4./)
  ! used in both hydrology modules
   REAL(r_std), PARAMETER, DIMENSION(nvmc)              :: throughfall_by_mtc = &
  & (/ 30., 30., 30., 30., 30., 30., 30., 30., 30., 30., 30., 30., 30. /)

  !------------------
  ! Albedo - sechiba
  !------------------
  !
  ! Initial snow albedo value for each vegetation type
  ! as it will be used in condveg_snow
  ! Values are from the Thesis of S. Chalita (1992)
  REAL(r_std), PARAMETER, DIMENSION(nvmc)     :: snowa_ini_mtc = &
  & (/ 0.35, 0.,   0.,   0.14, 0.14, &
  &    0.14, 0.14, 0.14, 0.14, 0.18, &
  &    0.18, 0.18, 0.18 /)
  !-
  ! Decay rate of snow albedo value for each vegetation type
  ! as it will be used in condveg_snow
  ! Values are from the Thesis of S. Chalita (1992)
  REAL(r_std), PARAMETER, DIMENSION(nvmc)     :: snowa_dec_mtc = &
  & (/ 0.45, 0.,   0.,   0.06, 0.06, &
  &    0.11, 0.06, 0.11, 0.11, 0.52, &
  &    0.52, 0.52, 0.52 /)
  !-
  ! leaf albedo of vegetation type, visible albedo
  REAL(r_std), PARAMETER, DIMENSION(nvmc)     :: alb_leaf_vis_mtc = &
  & (/ .00, .04, .06, .06, .06, &
  &    .06, .06, .06, .06, .10, &
  &    .10, .10, .10 /) 
  ! leaf albedo of vegetation type, near infrared albedo
  REAL(r_std), PARAMETER, DIMENSION(nvmc)     :: alb_leaf_nir_mtc = &
  & (/   .00, .20, .22, .22, .22, &
  &      .22, .22, .22, .22, .30, &
  &      .30, .30, .30   /)


  !------------------------
  !   Soil - vegetation
  !------------------------
  !
  ! Table which contains the correlation between the soil types
  ! and vegetation type. Two modes exist :
  !  1) pref_soil_veg = 0 then we have an equidistribution
  !     of vegetation on soil types
  !  2) Else for each pft the prefered soil type is given :
  !     1=sand, 2=loan, 3=clay
  ! The variable is initialized in slowproc.
  INTEGER(i_std), PARAMETER, DIMENSION(nvmc)     :: pref_soil_veg_sand_mtc = &
  & (/ 1, 3, 3, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2 /)

  INTEGER(i_std), PARAMETER, DIMENSION(nvmc)     :: pref_soil_veg_loan_mtc = &
  & (/ 2, 2, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3 /)

  INTEGER(i_std), PARAMETER, DIMENSION(nvmc)     :: pref_soil_veg_clay_mtc = &
  & (/ 3, 1, 1, 1, 1, 1 ,1 ,1 ,1 ,1 ,1 ,1, 1 /)

  !----------------
  ! Photosynthesis
  !----------------
  !-
  ! 1 .CO2
  !-
  ! flag for C4 vegetation types
  LOGICAL,PARAMETER, DIMENSION(nvmc) ::    is_c4_mtc  =        &  
  & (/.FALSE.,.FALSE.,.FALSE.,.FALSE.,.FALSE.,.FALSE.,         &
  &   .FALSE.,.FALSE.,.FALSE.,.FALSE.,.TRUE.,.FALSE.,.TRUE. /)
  !-
  ! Slope of the gs/A relation (Ball & al.)
  REAL(r_std),PARAMETER, DIMENSION(nvmc)   ::   gsslope_mtc = &
  & (/0., 9., 9., 9., 9., 9., 9., 9., 9., 9., 3., 9., 3./)
  !-
  ! intercept of the gs/A relation (Ball & al.)
  REAL(r_std),PARAMETER, DIMENSION(nvmc)  ::  gsoffset_mtc  = &
  & (/ 0.0,  0.01, 0.01, 0.01, 0.01, 0.01,         &
  &    0.01, 0.01, 0.01, 0.01, 0.03, 0.01, 0.03 /)
  !-
  ! values used for vcmax when STOMATE is not activated
  REAL(r_std),PARAMETER, DIMENSION(nvmc)  :: vcmax_fix_mtc = &
  & (/  0., 40., 50., 30., 35., 40.,        &
  &    30., 40., 35., 60., 60., 70., 70. /)
  !-
  ! values used for vjmax when STOMATE is not activated
  REAL(r_std),PARAMETER, DIMENSION(nvmc)  :: vjmax_fix_mtc = &
  & (/ 0., 80., 100., 60., 70., 80.,          &
  &   60., 80., 70., 120., 120., 140., 140. /)
  !-
  ! values used for photosynthesis tmin when STOMATE is not activated
  REAL(r_std),PARAMETER, DIMENSION(nvmc)  :: co2_tmin_fix_mtc = &
  &  (/ 0.,  2.,  2., -4., -3., -2.,        &
  &    -4., -4., -4., -5.,  6., -5.,  6. /)
  !-
  ! values used for photosynthesis topt when STOMATE is not activated
  REAL(r_std),PARAMETER, DIMENSION(nvmc)  :: co2_topt_fix_mtc  =  &
  & (/  0.,  27.5, 27.5, 17.5, 25.,  20.,          &
  &    17.5, 17.5, 17.5, 20.,  32.5, 20.,  32.5 /)
  !-
  ! values used for photosynthesis tmax when STOMATE is not activated
  REAL(r_std),PARAMETER, DIMENSION(nvmc)  :: co2_tmax_fix_mtc  =  &
  & (/ 0., 55., 55., 38., 48., 38.,            &
  &    38., 38., 38., 45., 55., 45., 55. /)
  !-
  ! 2 .Stomate
  !-
  ! extinction coefficient of the Monsi&Seaki relationship (1953)
  REAL(r_std),PARAMETER, DIMENSION(nvmc)   :: ext_coeff_mtc =  &
  & (/.5, .5, .5, .5, .5, .5, .5, .5, .5, .5, .5, .5, .5/)
  !-
  ! Maximum rate of carboxylation
  REAL(r_std), PARAMETER, DIMENSION(nvmc)    :: vcmax_opt_mtc   =    &
  & (/ undef,     65.,     65.,     35.,     45.,     55.,     35.,   &
  &         45.,     35.,     70.,     70.,    70.,    70.      /)
  !-
  ! Maximum rate of RUbp regeneration
  REAL(r_std), PARAMETER, DIMENSION(nvmc)  :: vjmax_opt_mtc        =     &   
  & (/   undef,    130.,    130.,     70.,     80.,    110.,     70.,      &
  &           90.,     70.,    160.,    160.,    200.,    200.      /)
!-!
  ! minimum photosynthesis temperature, 
  ! constant a of ax^2+bx+c (deg C), tabulated
  REAL(r_std),  PARAMETER, DIMENSION(nvmc)    :: tphoto_min_a_mtc  =       &
  & (/   undef,      0.,      0.,      0.,      0.,      0.,      0.,       &
  &            0.,      0.,  0.0025,      0.,      0.,      0.           /)
  !-
  ! minimum photosynthesis temperature, 
  ! constant b of ax^2+bx+c (deg C), tabulated
  REAL(r_std), PARAMETER, DIMENSION(nvmc)      :: tphoto_min_b_mtc  =      &
  & (/  undef,        0.,      0.,      0.,      0.,      0.,      0.,      &
  &            0.,      0.,     0.1,      0.,      0.,      0.           /)
  !-
  ! minimum photosynthesis temperature, 
  ! constant c of ax^2+bx+c (deg C), tabulated
  REAL(r_std),  PARAMETER, DIMENSION(nvmc)     :: tphoto_min_c_mtc =        &
  & (/   undef,      2.,      2.,     -4.,     -3.,     -2.,     -4.,        &
  &           -4.,     -4.,   -3.25,     13.,     -5.,     13.           /)
!-!
  ! optimum photosynthesis temperature, 
  ! constant a of ax^2+bx+c (deg C), tabulated
  REAL(r_std),  PARAMETER, DIMENSION(nvmc)     :: tphoto_opt_a_mtc =         &
  & (/   undef,      0.,      0.,      0.,      0.,      0.,      0.,         &
  &              0.,      0.,  0.0025,      0.,      0.,      0.           /)
  !-
  ! optimum photosynthesis temperature, 
  ! constant b of ax^2+bx+c (deg C), tabulated
  REAL(r_std),  PARAMETER, DIMENSION(nvmc)     :: tphoto_opt_b_mtc  =      &
  & (/   undef,      0.,      0.,      0.,      0.,      0.,      0.,       &
  &            0.,      0.,    0.25,      0.,      0.,      0.           /)
  ! optimum photosynthesis temperature, 
  ! constant c of ax^2+bx+c (deg C), tabulated
  REAL(r_std), PARAMETER, DIMENSION(nvmc)      :: tphoto_opt_c_mtc  =        &
  & (/  undef,      37.,     37.,     25.,     32.,     26.,     25.,         &
  &           25.,     25.,   27.25,     36.,     30.,     36.           /)
!-!
  ! maximum photosynthesis temperature, 
  ! constant a of ax^2+bx+c (deg C), tabulated
  REAL(r_std), PARAMETER, DIMENSION(nvmc)       :: tphoto_max_a_mtc  =      &
  & (/  undef,       0.,      0.,      0.,      0.,      0.,      0.,        &
  &            0.,      0., 0.00375,      0.,      0.,      0.            /)
  !-
  ! maximum photosynthesis temperature, 
  ! constant b of ax^2+bx+c (deg C), tabulated
  REAL(r_std),  PARAMETER, DIMENSION(nvmc)       :: tphoto_max_b_mtc  =     &
  & (/   undef,      0.,      0.,      0.,      0.,      0.,      0.,        &
  &            0.,      0.,    0.35,      0.,      0.,      0.            /)
  !-
  ! maximum photosynthesis temperature, 
  ! constant c of ax^2+bx+c (deg C), tabulated
  REAL(r_std),  PARAMETER, DIMENSION(nvmc)        :: tphoto_max_c_mtc  =    &
  & (/  undef,      55.,     55.,     38.,     48.,     38.,     38.,         &
  &           38.,     38.,  41.125,     55.,     45.,     55.            /)


  !----------------------
  ! Respiration - stomate
  !----------------------
  !
!-! slope of maintenance respiration coefficient (1/K), 
  ! constant c of aT^2+bT+c , tabulated
  REAL(r_std), PARAMETER, DIMENSION(nvmc)     :: maint_resp_slope_c_mtc = &
  & (/  undef,     .12,     .12,     .16,     .16,     .16,     .16,           &
  &           .16,     .16,     .16,     .12,     .16,     .12                /)
  !-
  ! slope of maintenance respiration coefficient (1/K), 
  ! constant b of aT^2+bT+c , tabulated
  REAL(r_std), PARAMETER, DIMENSION(nvmc)       :: maint_resp_slope_b_mtc = &
  & (/   undef,      .0,      .0,      .0,      .0,      .0,      .0,        &
  &            .0,      .0, -.00133,      .0, -.00133,      .0                /)
  !-
  ! slope of maintenance respiration coefficient (1/K), 
  ! constant a of aT^2+bT+c , tabulated
  REAL(r_std), PARAMETER, DIMENSION(nvmc)       :: maint_resp_slope_a_mtc = &
  & (/  undef,       .0,      .0,      .0,      .0,      .0,      .0,         &
  &            .0,      .0,      .0,      .0,      .0,      .0                /)
!-! maintenance respiration coefficient (g/g/day) at 0 deg C,
  ! for leaves, tabulated
  REAL(r_std), PARAMETER, DIMENSION(nvmc) ::   cm_zero_leaf_mtc  =    &
  & (/  undef,  2.35E-3, 2.62E-3, 1.01E-3, 2.35E-3, 2.62E-3, 1.01E-3,      &
  &       2.62E-3, 2.05E-3, 2.62E-3, 2.62E-3, 2.62E-3, 2.62E-3            /)
  !-
  ! maintenance respiration coefficient (g/g/day) at 0 deg C,
  ! for sapwood above, tabulated
  REAL(r_std), PARAMETER, DIMENSION(nvmc) ::   cm_zero_sapabove_mtc =    &
  & (/ undef,  1.19E-4, 1.19E-4, 1.19E-4, 1.19E-4, 1.19E-4, 1.19E-4,        &
  &       1.19E-4, 1.19E-4, 1.19E-4, 1.19E-4, 1.19E-4, 1.19E-4             /)
  !-
  ! maintenance respiration coefficient (g/g/day) at 0 deg C,
  ! for sapwood below, tabulated
  REAL(r_std), PARAMETER, DIMENSION(nvmc) ::  cm_zero_sapbelow_mtc =    &
  & (/ undef,   1.19E-4, 1.19E-4, 1.19E-4, 1.19E-4, 1.19E-4, 1.19E-4,      &
  &       1.19E-4, 1.19E-4, 1.19E-4, 1.19E-4, 1.19E-4, 1.19E-4            /)
  !-
  ! maintenance respiration coefficient (g/g/day) at 0 deg C,
  ! for heartwood above, tabulated
  REAL(r_std), PARAMETER, DIMENSION(nvmc) ::   cm_zero_heartabove_mtc =  &
  & (/   undef,      0.,      0.,      0.,      0.,      0.,      0.,      &
  &            0.,      0.,      0.,      0.,      0.,      0.             /)
  !-
  ! maintenance respiration coefficient (g/g/day) at 0 deg C,
  ! for heartwood below, tabulated
  REAL(r_std), PARAMETER, DIMENSION(nvmc) ::   cm_zero_heartbelow_mtc =  &
  & (/  undef,      0.,      0.,      0.,      0.,      0.,      0.,       &
  &            0.,      0.,      0.,      0.,      0.,      0.              /)
  !-
  ! maintenance respiration coefficient (g/g/day) at 0 deg C,
  ! for roots, tabulated
  REAL(r_std), PARAMETER, DIMENSION(nvmc) ::  cm_zero_root_mtc  =    &
  & (/ undef,   1.67E-3, 1.67E-3, 1.67E-3, 1.67E-3, 1.67E-3, 1.67E-3,   &
  &       1.67E-3, 1.67E-3, 1.67E-3, 1.67E-3, 1.67E-3, 1.67E-3           /)
  !-
  ! maintenance respiration coefficient (g/g/day) at 0 deg C,
  ! for fruits, tabulated
  REAL(r_std), PARAMETER, DIMENSION(nvmc) ::  cm_zero_fruit_mtc  =   &
  & (/ undef,   1.19E-4, 1.19E-4, 1.19E-4, 1.19E-4, 1.19E-4, 1.19E-4,   &
  &       1.19E-4, 1.19E-4, 1.19E-4, 1.19E-4, 1.19E-4, 1.19E-4          /)
  !-
  ! maintenance respiration coefficient (g/g/day) at 0 deg C,
  ! for carbohydrate reserve, tabulated
  REAL(r_std), PARAMETER, DIMENSION(nvmc) ::  cm_zero_carbres_mtc   =   &
  & (/  undef,  1.19E-4, 1.19E-4, 1.19E-4, 1.19E-4, 1.19E-4, 1.19E-4,      &
  &       1.19E-4, 1.19E-4, 1.19E-4, 1.19E-4, 1.19E-4, 1.19E-4             /)


  !----------------
  ! Fire - stomate
  !---------------
  !
  ! flamability: critical fraction of water holding capacity
  REAL(r_std),PARAMETER, DIMENSION(nvmc)     ::  flam_mtc =  &
  & (/  undef,   .15,     .25,     .25,     .25,     .25,     .25,  &
  &          .25,     .25,     .25,     .25,     .35,     .35 /)
  !-
  ! fire resistance
  REAL(r_std),PARAMETER, DIMENSION(nvmc)  ::   resist_mtc =  &
  & (/ undef,   .95,     .90,     .12,     .50,     .12,     .12,   &
  &        .12,     .12,      .0,      .0,      .0,      .0 /) 


  !----------------
  ! Flux - LUC
  !---------------
  !
  ! Coeff of biomass export for the year
  REAL(r_std),PARAMETER, DIMENSION(nvmc)     :: coeff_lcchange_1_mtc = &
  & (/  undef,    0.597,     0.597,    0.597,     0.597,    0.597,   0.597,   &
  &           0.597,     0.597,    0.597,     0.597,    0.597,   0.597   /)
  !-
  ! Coeff of biomass export for the decade
  REAL(r_std),PARAMETER, DIMENSION(nvmc)     :: coeff_lcchange_10_mtc = &
  & (/ undef,   0.403,     0.403,    0.299,     0.299,    0.299,   0.299,   &
  &           0.299,     0.299,    0.299,     0.403,    0.299,   0.403   /)
  !-
  ! Coeff of biomass export for the century
  REAL(r_std),PARAMETER, DIMENSION(nvmc)     :: coeff_lcchange_100_mtc = &
  & (/ undef,    0.,        0.,    0.104,     0.104,    0.104,   0.104,   &
  &           0.104,     0.104,    0.104,        0.,    0.104,      0.   /)


  !-----------
  ! Phenology
  !-----------
  !-
  ! 1 .Stomate
  !-
  ! maximum LAI, PFT-specific
  REAL(r_std), PARAMETER, DIMENSION (nvmc)  :: lai_max_mtc =  &
  & (/ undef,    7.,     7.,      5.,      5.,      5.,     4.5,    &
  &        4.5,    3.0,     2.5,     2.5,     5.,     5.  /)
  !-
  ! which phenology model is used? (tabulated) 
  CHARACTER(len=6), PARAMETER, DIMENSION(nvmc) :: pheno_model_mtc =  &
  & (/  'none  ',   'none  ',   'moi   ',   'none  ',   'none  ',   &
  &     'ncdgdd',   'none  ',   'ncdgdd',   'ngd   ',   'moigdd',   &
  &     'moigdd',   'moigdd',   'moigdd'           /) 
  !-
  ! type of phenology
  ! 0=bared ground 1=evergreen,  2=summergreen,  3=raingreen,  4=perennial
  ! Pour l'instant, le phnotype de sol nu n'est pas gr aussi on traitera les sols nu comme "evergreen"
  INTEGER(i_std), PARAMETER, DIMENSION(nvmc)   :: pheno_type_mtc  =    &
  & (/  0,    1,        3,       1,       1,       2,       1,    &
  &         2,        2,       4,       4,       2,       3 /) 
  !-
  ! 2. Leaf Onset
  !-
!-! critical gdd, tabulated (C), constant c of aT^2+bT+c
  REAL(r_std), PARAMETER, DIMENSION(nvmc)     :: pheno_gdd_crit_c_mtc = &
  & (/ undef,  undef,   undef,   undef,   undef,   undef,   undef,  &
  &      undef,   undef,     270.,   400.,    125.,    400. /)
  !-
  ! critical gdd, tabulated (C), constant b of aT^2+bT+c
  REAL(r_std), PARAMETER, DIMENSION(nvmc)     :: pheno_gdd_crit_b_mtc = &
  & (/  undef,  undef,   undef,   undef,   undef,   undef,   undef, &
  &      undef,   undef,    6.25,      0.,      0.,       0. /)
  !-
  ! critical gdd, tabulated (C), constant a of aT^2+bT+c
  REAL(r_std), PARAMETER, DIMENSION(nvmc)      :: pheno_gdd_crit_a_mtc = &
  & (/ undef,   undef,   undef,   undef,   undef,   undef,   undef,  &
  &      undef,   undef, 0.03125,      0.,      0.,       0. /)
  !-
  ! critical ngd, tabulated. Threshold -5 degrees
  REAL(r_std), PARAMETER, DIMENSION(nvmc)     :: ngd_crit_mtc =  &
  & (/  undef,  undef,   undef,   undef,   undef,   undef,   undef, &
  &      undef,     17.,   undef,   undef,   undef,   undef /)
  !-
  ! critical temperature for the ncd vs. gdd function in phenology
  REAL(r_std), PARAMETER, DIMENSION(nvmc)   ::  ncdgdd_temp_mtc =  &
  & (/  undef,  undef,   undef,   undef,   undef,      5.,   undef, &
  &         0.,   undef,   undef,   undef,   undef,   undef /)
  !-
  ! critical humidity (relative to min/max) for phenology
  REAL(r_std), PARAMETER, DIMENSION(nvmc)   :: hum_frac_mtc =     &
  & (/    undef,   undef,      .5,   undef,   undef,   undef,   undef,   &
  &         undef,   undef,      .5,      .5,      .5,      .5         /)
  !-
  ! minimum duration of dormance (d) for phenology
  REAL(r_std), PARAMETER, DIMENSION(nvmc) ::  lowgpp_time_mtc =     &
  & (/  undef,    undef,     30.,   undef,   undef,     30.,   undef,   &
  &           30.,     30.,     30.,     30.,     30.,     30. /)
  !-
  ! minimum time elapsed since moisture minimum (d)
  REAL(r_std),PARAMETER , DIMENSION(nvmc)  :: hum_min_time_mtc =        &
  & (/ undef,     undef,     50.,   undef,   undef,   undef,   undef,    &
  &         undef,   undef,     35.,     35.,     75.,     75.           /) 
  !-
  ! sapwood -> heartwood conversion time (d)
  REAL(r_std) ,PARAMETER , DIMENSION(nvmc)   :: tau_sap_mtc          =     &
  & (/  undef,     730.,    730.,    730.,    730.,    730.,    730.,      &
  &          730.,    730.,   undef,   undef,   undef,   undef      /)
  !-
  ! fruit lifetime (d)
  REAL(r_std) ,PARAMETER , DIMENSION(nvmc)   ::    tau_fruit_mtc    =      & 
  & (/   undef,     90.,     90.,     90.,     90.,     90.,     90.,      &
  &           90.,     90.,   undef,   undef,   undef,   undef      /)
  !-
  ! fraction of primary leaf and root allocation put into reserve
  REAL(r_std) ,PARAMETER , DIMENSION(nvmc)   ::   ecureuil_mtc   =     &
  & (/ undef,        .0,      1.,      .0,      .0,      1.,      .0,   &
  &            1.,      1.,      1.,      1.,      1.,      1.      /)
  !-
  ! NEW - allocation above/below = f(age) - 30/01/04 NV/JO/PF
  REAL(r_std) ,PARAMETER , DIMENSION(nvmc)   ::   alloc_min_mtc   =               &
  & (/   undef,  0.2,       0.2,       0.2,       0.2,     0.2,     0.2,   &
  &             0.2,       0.2,     undef,     undef,   undef,   undef   /)
  !-
  REAL(r_std) ,PARAMETER , DIMENSION(nvmc)   ::   alloc_max_mtc  =        &
  & (/ undef,    0.8,       0.8,       0.8,       0.8,     0.8,     0.8,   &
  &             0.8,       0.8,     undef,     undef,   undef,   undef   /)
  !-
  REAL(r_std) ,PARAMETER , DIMENSION(nvmc)   ::   demi_alloc_mtc    =     &
  & (/ undef,    5.,        5.,       5.,        5.,       5.,      5.,   &
  &              5.,        5.,    undef,     undef,    undef,   undef   /)

  !>> DS new for merge in the trunk
  ! 15/06/2011 : add leaflife_mtc for the new formalism used for calculate sla
  REAL(r_std) ,PARAMETER , DIMENSION(nvmc)   ::   leaflife_mtc = &
  & (/  undef,      .5,      2.,     .33,      1.,     2.,      .33,   &
  &            2.,      2.,      2.,      2.,     2.,        2. /)

  !-
  ! 3. Senescence
  !-
  ! length of death of leaves, tabulated (d)
  REAL(r_std), PARAMETER, DIMENSION(nvmc)  ::       leaffall_mtc  =     &
  & (/ undef,     undef,     10.,   undef,   undef,     10.,   undef,        &
  &           10.,     10.,     10.,     10.,     10.,     10.        /)
  !-
  ! critical leaf age, tabulated (d)
  REAL(r_std),PARAMETER, DIMENSION(nvmc)   :: leafagecrit_mtc  =         &
  & (/  undef,     730.,    180.,    910.,    730.,    180.,    910.,       &
  &          180.,    180.,    120.,    120.,    90.,    90.            /)
  !-
  ! type of senescence, tabulated
  CHARACTER(len=6),PARAMETER, DIMENSION(nvmc)  :: senescence_type_mtc  = &
  & (/  'none  ',  'none  ',   'dry   ',  'none  ',  'none  ',   &
  &     'cold  ',  'none  ',   'cold  ',  'cold  ',  'mixed ',   &
  &     'mixed ',  'mixed ',   'mixed '            /)
  !-
  ! critical relative moisture availability for senescence
  REAL(r_std),PARAMETER, DIMENSION(nvmc)   :: senescence_hum_mtc  = &
  & (/ undef,      undef,      .3,   undef,   undef,   undef,   undef,    &
  &         undef,   undef,      .2,      .2,      .3,      .2            /)
  !-
  ! relative moisture availability above which 
  ! there is no humidity-related senescence
  REAL(r_std),PARAMETER, DIMENSION(nvmc)   :: nosenescence_hum_mtc  =    &
  & (/  undef,    undef,      .8,   undef,   undef,   undef,   undef,      &
  &               undef,   undef,      .3,      .3,      .3,      .3       /)
  !-
  ! maximum turnover time for grasse
  REAL(r_std),PARAMETER, DIMENSION(nvmc)   :: max_turnover_time_mtc  =    &
  & (/ undef,    undef,   undef,    undef,   undef,   undef,   undef,        &
  &         undef,   undef,      80.,     80.,     80.,     80.            /)
  !-
  ! minimum turnover time for grasse
  REAL(r_std),PARAMETER, DIMENSION(nvmc)   :: min_turnover_time_mtc  =    &
  & (/ undef,     undef,    undef,    undef,    undef,   undef,   undef,    &
  &         undef,   undef,      10.,      10.,      10.,      10.          /)
  !-
  ! minimum leaf age to allow senescence g
  REAL(r_std),PARAMETER, DIMENSION(nvmc)   ::  min_leaf_age_for_senescence_mtc = &
  & (/ undef,   undef,    90.,   undef,   undef,    90.,    undef,          &
  &         60.,    60.,     30.,     30.,    30.,      30.          /)
!-!-
  ! critical temperature for senescence (C), 
  ! constant c of aT^2+bT+c , tabulated
  REAL(r_std),PARAMETER, DIMENSION(nvmc)   :: senescence_temp_c_mtc = &
  & (/  undef,    undef,   undef,   undef,   undef,     12.,   undef,    &
  &            7.,      2.,  -1.375,      5.,      5.,     10.           /)
  !-
  ! critical temperature for senescence (C), 
  ! constant b of aT^2+bT+c , tabulated
  REAL(r_std), PARAMETER, DIMENSION(nvmc)  :: senescence_temp_b_mtc = &
  & (/  undef,   undef,   undef,   undef,   undef,      0.,   undef,      &
  &            0.,      0.,      .1,      0.,      0.,      0.             /)
  !-
  ! critical temperature for senescence (C), 
  ! constant a of aT^2+bT+c , tabulated
  REAL(r_std),PARAMETER, DIMENSION(nvmc)   :: senescence_temp_a_mtc = &
  & (/ undef,    undef,   undef,   undef,   undef,      0.,   undef,    &
  &            0.,      0.,  .00375,      0.,      0.,      0.           /)


  !-----------
  ! DGVM
  !-----------
  !
  ! residence time (y) of trees
  REAL(r_std), PARAMETER, DIMENSION(nvmc)  :: residence_time_mtc = &
  & (/ undef,   30.0,    30.0,    40.0,    40.0,    40.0,    80.0,  &
  &       80.0,    80.0,     0.0,     0.0,     0.0,     0.0 /) 
  !-
  ! critical tmin, tabulated (C)
  REAL(r_std), PARAMETER, DIMENSION(nvmc)    :: tmin_crit_mtc = &
  & (/ undef,    0.0,     0.0,   -30.0,   -14.0,   -30.0,   -45.0, &
  &     -45.0,   undef,   undef,   undef,   undef,   undef /)
  !-
  ! critical tcm, tabulated (C)
  REAL(r_std), PARAMETER, DIMENSION(nvmc)     :: tcm_crit_mtc = &
  & (/  undef,  undef,   undef,     5.0,    15.5,    15.5,    -8.0, &
  &       -8.0,    -8.0,   undef,   undef,   undef,   undef /)


!------------------------
END MODULE constantes_mtc
